@@ -63,11 +63,11 @@ class RequestProviderMixin:
     """
     Mixin that provides a method which returns a django request.
     Supposed to be used in unittests that require a request object.
-    Adds also the message middleware so django messages can be tested.
+    Also adds the message middleware so django messages can be tested.
     """
 
     @staticmethod
-    def build_test_request(user: AbstractBaseUser = None):
+    def get_request(user: AbstractBaseUser = None):
         """
         Creates and returns a django request.
         """
@@ -77,13 +77,13 @@ class RequestProviderMixin:
         request.user = user
 
         # Annotate a request object with a session
-        middleware = SessionMiddleware()
-        middleware.process_request(request)
+        session_middleware = SessionMiddleware()
+        session_middleware.process_request(request)
         request.session.save()
 
         # Annotate a request object with messages
-        middleware = MessageMiddleware()
-        middleware.process_request(request)
+        message_middleware = MessageMiddleware()
+        message_middleware.process_request(request)
         request.session.save()
 
         return request
